package calcolo_media;

import java.util.Stack;

/**
 * Oggetto usato per lo scambio di dati tra il produttore e il consumatore.
 * La classe  thread-safe.
 *
 * @author <a href="mailto:ervincio@tiscali.it">Vincenzo Manzoni</a>
 */

public class Buffer {

        /** Uso come modello di salvataggio di dati lo Stack (LIFO).*/
        private Stack data;

        /**
         * Istanzio un oggetto Buffer.
         */
        public Buffer() {
                this.data = new Stack();
        }

        /**
         * Aggiunge un oggetto allo stack.
         * Il metodo  <code>synchronized</code>.
         *
         * @param item Oggetto da inserire nello Stack.
         */
        public synchronized void add(Object item) {
                data.push(item);
        }

        /**
         * Recupera un oggetto dallo stack.
         * Il metodo  <code>synchronized</code>.
         *
         * @return Oggetto contenuto nello stack.
         */
        public synchronized Object remove() {
                return data.pop();
        }

        /**
         * Verifica se lo stack  vuoto.
         * Il metodo  <code>synchronized</code>.
         *
         * @return <code>true</code> se lo stack  vuoto, altrimenti
         *         <code>false</code>.
         */
        public synchronized boolean isEmpty() {
                synchronized (data) {
                        return data.isEmpty();
                }
        }
}
